==> jc-1.4.0.tar.gz: soot/jimple/spark/fieldrw/FieldReadTag.h <==
// public class soot.jimple.spark.fieldrw.FieldReadTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 26c009a8a59d47e0 soot_jimple_spark_fieldrw_FieldRWTag
// @dep_class 5c6a8447c13f5d0d soot_jimple_spark_fieldrw_FieldReadTag

// header file dependencies
// @dep_header soot_jimple_spark_fieldrw_FieldRWTag

#include "soot/jimple/spark/fieldrw/FieldRWTag.h"

#ifndef _JC_soot_jimple_spark_fieldrw_FieldReadTag_H_
#define _JC_soot_jimple_spark_fieldrw_FieldReadTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_refs	_jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_nonrefs	_jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$refs	_jc_soot_jimple_spark_fieldrw_FieldReadTag$refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$nonrefs	_jc_soot_jimple_spark_fieldrw_FieldReadTag$nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object	_jc_soot_jimple_spark_fieldrw_FieldReadTag$object;

typedef const struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vmethods	_jc_soot_jimple_spark_fieldrw_FieldReadTag$vmethods;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vtable	_jc_soot_jimple_spark_fieldrw_FieldReadTag$vtable;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vtype	_jc_soot_jimple_spark_fieldrw_FieldReadTag$vtype;

// Constructors
extern void _jc_soot_jimple_spark_fieldrw_FieldReadTag$method$_init$4239edc3ba8b9760(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldReadTag$method_info$getName$bec186f2ce7e1882;

// Virtual methods structure
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *);
};

// Vtable
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vmethods	soot_jimple_spark_fieldrw_FieldRWTag;
	_jc_soot_jimple_spark_fieldrw_FieldReadTag$vmethods	soot_jimple_spark_fieldrw_FieldReadTag;
};

// Vtype
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_fieldrw_FieldReadTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$refs {
    _jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_refs	soot_jimple_spark_fieldrw_FieldReadTag;
    _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_refs	soot_jimple_spark_fieldrw_FieldRWTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_nonrefs	soot_jimple_spark_fieldrw_FieldRWTag;
    _jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_nonrefs	soot_jimple_spark_fieldrw_FieldReadTag;
};

// Object instance structure
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object {
	_jc_soot_jimple_spark_fieldrw_FieldReadTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_fieldrw_FieldReadTag$vtype	*vtype;
	_jc_soot_jimple_spark_fieldrw_FieldReadTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_fieldrw_FieldReadTag$vtype _jc_soot_jimple_spark_fieldrw_FieldReadTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_fieldrw_FieldReadTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_fieldrw_FieldReadTag$class_object;

#endif	/* _JC_soot_jimple_spark_fieldrw_FieldReadTag_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/fieldrw/FieldReadTag.h <==
// public class soot.jimple.spark.fieldrw.FieldReadTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 26c009a8a59d47e0 soot_jimple_spark_fieldrw_FieldRWTag
// @dep_class 5c6a8447c13f5d0d soot_jimple_spark_fieldrw_FieldReadTag

// header file dependencies
// @dep_header soot_jimple_spark_fieldrw_FieldRWTag

#include "soot/jimple/spark/fieldrw/FieldRWTag.h"

#ifndef _JC_soot_jimple_spark_fieldrw_FieldReadTag_H_
#define _JC_soot_jimple_spark_fieldrw_FieldReadTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_refs	_jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_nonrefs	_jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$refs	_jc_soot_jimple_spark_fieldrw_FieldReadTag$refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$nonrefs	_jc_soot_jimple_spark_fieldrw_FieldReadTag$nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object	_jc_soot_jimple_spark_fieldrw_FieldReadTag$object;

typedef const struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vmethods	_jc_soot_jimple_spark_fieldrw_FieldReadTag$vmethods;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vtable	_jc_soot_jimple_spark_fieldrw_FieldReadTag$vtable;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vtype	_jc_soot_jimple_spark_fieldrw_FieldReadTag$vtype;

// Constructors
extern void _jc_soot_jimple_spark_fieldrw_FieldReadTag$method$_init$4239edc3ba8b9760(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_fieldrw_FieldReadTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldReadTag$method_info$getName$bec186f2ce7e1882;

// Virtual methods structure
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vmethods	soot_jimple_spark_fieldrw_FieldRWTag;
	_jc_soot_jimple_spark_fieldrw_FieldReadTag$vmethods	soot_jimple_spark_fieldrw_FieldReadTag;
};

// Vtype
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_fieldrw_FieldReadTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$refs {
    _jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_refs	soot_jimple_spark_fieldrw_FieldReadTag;
    _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_refs	soot_jimple_spark_fieldrw_FieldRWTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_nonrefs	soot_jimple_spark_fieldrw_FieldRWTag;
    _jc_soot_jimple_spark_fieldrw_FieldReadTag$sub_nonrefs	soot_jimple_spark_fieldrw_FieldReadTag;
};

// Object instance structure
struct _jc_soot_jimple_spark_fieldrw_FieldReadTag$object {
	_jc_soot_jimple_spark_fieldrw_FieldReadTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_fieldrw_FieldReadTag$vtype	*vtype;
	_jc_soot_jimple_spark_fieldrw_FieldReadTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_fieldrw_FieldReadTag$vtype _jc_soot_jimple_spark_fieldrw_FieldReadTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_fieldrw_FieldReadTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_fieldrw_FieldReadTag$class_object;

#endif	/* _JC_soot_jimple_spark_fieldrw_FieldReadTag_H_ */
